@@ -46,6 +46,7 @@ from telemeta.models.location import LocationRelation, Location
 from telemeta.models.system import Revision
 from telemeta.models.query import *
 from telemeta.models.instrument import *
+from telemeta.models.enum import *
 from django.forms import ModelForm
 
 
@@ -134,6 +135,7 @@ class MediaCollection(MediaResource):
     items_done            = CharField(_('items finished'))
     collector_is_creator  = BooleanField(_('recordist identical to depositor'))
     is_published          = BooleanField(_('published'))
+    conservation_site     = CharField(_('conservation site'))
     
     # Technical data
     code                  = CharField(_('code'), unique=True, required=True, validators=[is_valid_collection_code])
@@ -149,7 +151,7 @@ class MediaCollection(MediaResource):
     
     # All
     objects               = MediaCollectionManager()
- 
+        
     def __unicode__(self):
         return self.code
 
@@ -208,11 +210,12 @@ class MediaCollection(MediaResource):
         
     class Meta(MetaCore):
         db_table = 'media_collections'
+        ordering = ['code']
     
 class MediaCollectionForm(ModelForm):
     class Meta:
         model = MediaCollection
-
+        
 
 item_published_code_regex    = '[A-Za-z0-9._-]*'
 item_unpublished_code_regex  = '[A-Za-z0-9._-]*'
@@ -238,9 +241,9 @@ class MediaItem(MediaResource):
     cultural_area         = CharField(_('cultural area'))
     ethnic_group          = WeakForeignKey('EthnicGroup', related_name="items", 
                                            verbose_name=_('population / social group'))
-    context_comment       = TextField(_('comments'))
-    moda_execut           = CharField(_('moda_execut'))
     language              = CharField(_('language'))
+    context_comment       = TextField(_('comments / ethnographic context'))
+    moda_execut           = CharField(_('moda_execut'))
     
     # Musical informations
     vernacular_style      = WeakForeignKey('VernacularStyle', related_name="items", 
@@ -282,6 +285,8 @@ class MediaItem(MediaResource):
 
     class Meta(MetaCore):
         db_table = 'media_items'
+        permissions = (("can_play_all_items", "Can play all media items"), 
+                       ("can_download_all_items", "Can download all media items"), )
 
     def is_valid_code(self, code):
         "Check if the item code is well formed"
@@ -323,10 +328,6 @@ class MediaItem(MediaResource):
 class MediaItemForm(ModelForm):
     class Meta:
         model = MediaItem
-    
-    def __init__(self, *args, **kwds):
-        super(MediaItemForm, self).__init__(*args, **kwds)
-        self.fields['location'].queryset = Location.objects.order_by('name')
         
 class MediaItemKeyword(ModelCore):
     "Item keyword"
@@ -363,6 +364,24 @@ class MediaItemPerformanceForm(ModelForm):
         super(MediaItemPerformanceForm, self).__init__(*args, **kwds)
         self.fields['instrument'].queryset = Instrument.objects.order_by('name')
         self.fields['alias'].queryset = InstrumentAlias.objects.order_by('name')
+
+class MediaItemAnalysis(ModelCore):
+    "Item analysis result computed by TimeSide"
+
+    element_type = 'analysis'    
+    item  = ForeignKey('MediaItem', related_name="analysis", verbose_name=_('item'))
+    analyzer_id = CharField(_('id'), required=True)
+    name = CharField(_('name'))
+    value = CharField(_('value'))
+    unit = CharField(_('unit'))
+    
+    class Meta(MetaCore):
+        db_table = 'media_analysis'
+        ordering = ['name']
+        
+    def to_dict(self):
+        return {'id': self.analyzer_id, 'name': self.name, 'value': self.value, 'unit': self.unit}
+        
         
 class MediaPart(MediaResource):
     "Describe an item part"
@@ -379,7 +398,7 @@ class MediaPart(MediaResource):
         return self.title
 
 class Playlist(ModelCore):
-    "Item or collection playlist"
+    "Item, collection or marker playlist"
     element_type = 'playlist'
     public_id      = CharField(_('public_id'), required=True)
     author         = ForeignKey(User, related_name="playlists", db_column="author")
@@ -431,6 +450,19 @@ class MediaItemMarker(MediaResource):
         else:
             return self.public_id
 
+
+class MediaItemTranscodingFlag(ModelCore):
+    "Item flag to know if the MediaItem has been transcoded to a given format"
+    
+    item            = ForeignKey('MediaItem', related_name="transcoding", verbose_name=_('item'))
+    mime_type       = CharField(_('mime_type'), required=True)
+    date            = DateTimeField(_('date'), auto_now=True)
+    value           = BooleanField(_('transcoded'))
+    
+    class Meta(MetaCore):
+        db_table = 'media_transcoding'
+
+
 class Search(ModelCore):
     "Keywork search"
     
